import { ElementRef, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { FormControl } from '@angular/forms';
import { BehaviorSubject, Subject } from 'rxjs';
import { GeocoderService } from './angular-geocoder.service';
import { ParsedPlaceObject, SuggestObjectWithHighlight } from './locatieserver.model';
import { GeocoderHistoryService } from './geocoder-history.service';
import * as i0 from "@angular/core";
export declare class GeocoderComponent implements OnInit, OnChanges {
    private geocoderService;
    private geocoderHistoryService;
    SEARCH_CHARACTER_THRESHOLD: number;
    readonly geocoderRef: import("@angular/core").Signal<ElementRef<any>>;
    readonly type: import("@angular/core").InputSignal<"hectometerpaal" | "appartementsrecht" | "waterschap" | "buurt" | "wijk" | "perceel" | "adres" | "postcode" | "weg" | "woonplaats" | "gemeente" | "provincie">;
    readonly searchInput: import("@angular/core").InputSignal<string>;
    readonly placeholder: import("@angular/core").InputSignal<string>;
    readonly resultCountLimit: import("@angular/core").InputSignal<number>;
    readonly province: import("@angular/core").InputSignal<string>;
    readonly fullscreen: import("@angular/core").InputSignal<boolean>;
    readonly microphone: import("@angular/core").InputSignal<boolean>;
    readonly boxshadow: import("@angular/core").InputSignal<boolean>;
    readonly borderradius: import("@angular/core").InputSignal<boolean>;
    readonly placeFound: import("@angular/core").OutputEmitterRef<ParsedPlaceObject>;
    readonly clearResults: import("@angular/core").OutputEmitterRef<any>;
    readonly query: import("@angular/core").OutputEmitterRef<string>;
    readonly freeSearchResults: import("@angular/core").OutputEmitterRef<ParsedPlaceObject[]>;
    readonly blur: import("@angular/core").OutputEmitterRef<any>;
    get hostGeocoderClass(): boolean;
    readonly hasFocus: import("@angular/core").WritableSignal<boolean>;
    speechRecognizer: any | undefined;
    formattedPlaceholder: import("@angular/core").Signal<string>;
    searchControl: FormControl<string>;
    readonly microphoneActive: import("@angular/core").WritableSignal<boolean>;
    userGpsLocation$: Subject<{
        lat: number;
        lon: number;
    }>;
    suggest$: import("rxjs").Observable<{
        places: SuggestObjectWithHighlight[];
    }>;
    reverseSuggest$: import("rxjs").Observable<({
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    useMyLocationPlace: any;
    private historyWithTypeFilter$;
    tooFewCharacters$: import("rxjs").Observable<any[]>;
    places$: import("rxjs").Observable<any[] | SuggestObjectWithHighlight[] | ({
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    readonly places: import("@angular/core").Signal<any[] | SuggestObjectWithHighlight[] | ({
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: import("geojson").GeoJSON;
        geometrie_rd: import("geojson").GeoJSON;
        centroide_rd: import("geojson").GeoJSON;
        centroide_ll: import("geojson").GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    foundPlace$: BehaviorSubject<any>;
    selectedIndex: number;
    readonly lookupResponseFound: import("@angular/core").WritableSignal<boolean>;
    clickout(event: any): void;
    constructor(geocoderService: GeocoderService, geocoderHistoryService: GeocoderHistoryService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    private suggest;
    private reverse;
    lookup(id: string): Promise<void>;
    reverseGeocode(): Promise<void>;
    free(): Promise<void>;
    clear(event: Event): void;
    clearPlaces(): void;
    handleSuggestClick(id: 'gps' | string): Promise<void>;
    handleEnter(places: SuggestObjectWithHighlight[]): void;
    reachedThreshold$: import("rxjs").Observable<boolean>;
    noPlacesFound$: import("rxjs").Observable<boolean>;
    noResult$: import("rxjs").Observable<boolean>;
    readonly noResult: import("@angular/core").Signal<boolean>;
    readonly isNoResultsFound: import("@angular/core").Signal<boolean>;
    fillInput(content: string, emitEvent?: boolean): void;
    isHighlighted(i: number): boolean;
    moveUp(): void;
    moveDown(places: SuggestObjectWithHighlight[]): void;
    resetIndex(): void;
    canQuery(): boolean;
    canClear(): boolean;
    formatPlaceholder(placeholder: string): string;
    showSuggestions(): void;
    private getSpeechRecognition;
    speechToText(event: any): any;
    private hideResults;
    private getGpsLocation;
    private formatSearchTerm;
    static ɵfac: i0.ɵɵFactoryDeclaration<GeocoderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GeocoderComponent, "angular-geocoder", never, { "type": { "alias": "type"; "required": false; "isSignal": true; }; "searchInput": { "alias": "searchInput"; "required": false; "isSignal": true; }; "placeholder": { "alias": "placeholder"; "required": false; "isSignal": true; }; "resultCountLimit": { "alias": "resultCountLimit"; "required": false; "isSignal": true; }; "province": { "alias": "province"; "required": false; "isSignal": true; }; "fullscreen": { "alias": "fullscreen"; "required": false; "isSignal": true; }; "microphone": { "alias": "microphone"; "required": false; "isSignal": true; }; "boxshadow": { "alias": "boxshadow"; "required": false; "isSignal": true; }; "borderradius": { "alias": "borderradius"; "required": false; "isSignal": true; }; }, { "placeFound": "placeFound"; "clearResults": "clearResults"; "query": "query"; "freeSearchResults": "freeSearchResults"; "blur": "blur"; }, never, never, false, never>;
}
